FHCRC.HVTNFCS <- function(myFCSobj,
                          gate1.vars=c(1,2),
                          gate2.vars=c(5,7),
                          gate3.vars=c(3,4),
                          MY.DEBUG=FALSE) {

  ## This function uses iGate and extractGatedData/subset.FCS to obtain the correct
  ## gated dataset for further analysis (using runtests.FCS)

  ## gate1:bidcut: Forward Scatter VS Side Scatter
  ##  (assumed to be column variable 1 and 2)
  ##                     (want the lymphocytes--central cluster) 
  ## gate2:bidcut: cd3 VS cd8
  ##  (assumed to be column variable 7 and 5)
  ##              (Select cd3+/cd8- (gate2.1)  and cd3+/cd8+ (gate2.2))
  ## gate3:biscut: cd69 vs Interferon Gamma
  ##  (assumed to be column variable 4 and 3)
  ##               (Select +/+ which are the cd4+ cells (for gate2.1)
  #                  cd8+ cells (for gate2.2))

  ## will output the augmented data matrix of the FCS object with the indices of the sequential gates

  ## to subset, only the last gate can be subseted
 

  ## gate 1:
  cat("\n")
  cat("\n")
  cat("Gate 1-bipcut: Select lymphocytes (the central cluster) from Foward Scatter vs Side Scatter", "\n")
  cat("\n")
  myFCSobj <- icreateGate(myFCSobj,
                    type="bidcut",
                    varpos=gate1.vars,
                    comment="FHCRC.HVTNFCS:gate1:Lymphocytes",
                    MY.DEBUG=MY.DEBUG)
  gatepos.1 <- dim(myFCSobj@gate)[2]
 ## gate 2:

  cat("\n")
  cat("Gate 2-biscut: Select cd8-/cd3+  and cd8+/cd3+ quadrant cells", "\n")
  cat("\n")
  cat("   Gate 2.1: Select the quadrant of cd8 negative cd3 positive cells (biscut.quadrant=-/+)", "\n")
  cat("\n")
  myFCSobj <- icreateGate(myFCSobj, type="biscut",
                    biscut.quadrant="-/+",
                    varpos=gate2.vars,
                    prev.gateNum=gatepos.1,
                    prev.IndexValue.In=1,
                    comment="FHCRC.HVTNFCS:gate2.1:cd8-/cd3+",
                    MY.DEBUG=MY.DEBUG)
  gatepos.2.1<- dim(myFCSobj@gate)[2]

  
  cat("\n")
  cat("   Gate 2.2: Select the quadrant of cd8 positive cd3 positive cells (biscut.quadrant=+/+)", "\n")
  cat("\n") 
 
  gatingrange <- extractGateHistory(myFCSobj, gateNum=gatepos.2.1)$gatingrange
  myFCSobj <- createGate(myFCSobj,
                         varpos=gate2.vars, 
                         gatingrange=gatingrange,
                         type="biscut",
                         biscut.quadrant="+/+",
                         prev.gateNum=gatepos.1,
                         prev.IndexValue.In=1,
                         comment="FHCRC.HVTNFCS:gate2.2:cd8+/cd3+",
                         MY.DEBUG=MY.DEBUG)
                
  gatepos.2.2 <- dim(myFCSobj@gate)[2]
  
  showgate.FCS(myFCSobj@data[,gate2.vars],
               gatingrange=gatingrange,
               Index=myFCSobj@gate[myFCSobj@current.data.obs,gatepos.2.2],
               type="biscut",
               biscut.quadrant="+/+",
               IndexValue.In=1,
               coltype="white")


 
  ## gate 3:
  cat("\n")
  cat("Gate 3-biscut: Select +/+ quadrant cells of IFNgamma and cd69", "\n")
  cat("\n")
  cat("   From Gate 2.1, Select the +/+ quadrant containing the cd4+ cells", "\n")
  cat("\n")
  myFCSobj <- icreateGate(myFCSobj, type="biscut",
                    biscut.quadrant="+/+",
                    varpos=gate3.vars,
                    prev.gateNum=gatepos.2.1,
                    comment="FHCRC.HVTNFCS:gate3.1:cd4+",
                    prev.IndexValue.In=1,
                    MY.DEBUG=MY.DEBUG)
  
  cat("\n")
  cat("   From Gate 2.2, Select the +/+ quadrant containing the cd8+ cells", "\n")
  cat("\n")
  cat("\n")
  myFCSobj <- icreateGate(myFCSobj, type="biscut",
                    biscut.quadrant="+/+",
                    varpos=gate3.vars,
                    prev.gateNum=gatepos.2.2,
                    prev.IndexValue.In=1,
                    comment="FHCRC.HVTNFCS:gate3.2:cd8+",
                    MY.DEBUG=MY.DEBUG)
  
  return(myFCSobj)
  
  
}
