
KS.flowcytest <- function(controldata,
                          stimuldata,
                          title="",
                          varname="",
                          yupper=0.01,
                          xlimit=c(0,1025),
                          alternative="two.sided",
                          KS.plotted=TRUE,
                          MY.DEBUG=TRUE, ...){
  
  lib.there <- require(stats)
  if(lib.there==FALSE){
    stop("Library ctest is needed and could not be found.")
  }

  controldata <- unlist(controldata)
  stimuldata <- unlist(stimuldata)
  if (MY.DEBUG){
    cat("FLOWCYTEST: KOLMOGOROV-SMIRNOV", "\n")
  }
  test <- ks.test(controldata, stimuldata, ...)
  if (MY.DEBUG){
    print(test)
  }

  ## plotting the densities
  if (KS.plotted==TRUE){
    plot(bkde(controldata), type="l", lty=2, col=2, xlab=varname,
         ylab="Estimated Density Using KernSmooth:bkde", xlim=xlimit, ylim=c(0,yupper ),
         main=paste(title, "Density Curve", sep=":") )
    lines(bkde(stimuldata), lty=3, col="blue")
    
    legend(xlimit[2]*1.2/3,yupper*9.5/10, c("control", "stimulated"),lty = c(2, 3), col=c(2,"blue"))
  }
  cat("\n\n\n")

  return(list(statistic=test$statistic, pval.2sid.KS=test$p.value, Alt.Hypoth.KS=test$alternative,
              method.KS=test$method, dataname.KS=test$data.name))
  
}

