boxplot.FCS <- function(x,
                        varpos=c(1), 
                        groups=NULL,
                        xlab,
                        ylab,
                        col,
                        alternating=TRUE,
                        do.out=FALSE,
                        ...
                        ){


    if (length(varpos) != 1) {
        stop("input 'varpos' can only be of length 1")
    }
    if((!is(x, "cytoSet")) && (!is(x[[1]], "FCS"))){
        stop("input 'object' must be a cytoSet object or a list of FCS objects")
    }
    data.toplot <-  vector("numeric")

    if(is(x, "cytosSet")){
        z <- vector("list")
        for (i in 1:length(x)){
            z[[i]]<- exprs(x[[i]])
        }
        data.toplot <- sapply(z, function(z){z[, varpos]})
    }

    if(is(x[[1]], "FCS")){
        if (is.list(x)){
            z<-lapply(x, fluors)
            data.toplot <- lapply(z, function(z){z[, varpos]})
        }
        else{
            data.toplot<- fluors(x)[, varpos]
        }
    }
    if (is.matrix(data.toplot)) data.toplot <- data.frame(data.toplot)

    lengthz <- lapply(data.toplot, function(x)length(x))
    data.toplot <- do.call(make.groups, data.toplot)

    if(!is.null(groups)){
        if (is.list(data.toplot)) {
            grouping <- factor(rep(groups, lengthz),levels=c(groups), ordered=TRUE)
            data.toplot <- cbind(data.toplot, "groups"=grouping)
        }
        
        bwplot( data ~ which | groups, data=data.toplot, as.table=TRUE,
               panel = function(...) {
                   panel.grid(v = 0, h = -1)
                   panel.bwplot( pch="|", fill=col,...)
               },
               par.settings = list(plot.symbol = list(pch = 4)),
               scales=list(relation="same", alternating=alternating, cex=1.5),
               xlab = xlab,
               ylab = ylab,
               cex.lab=1.5,
               do.out=do.out,
               ...)
        
    }
    else{
        bwplot( data ~ which, data=data.toplot, as.table=TRUE,
               panel = function(...) {
                   panel.grid(v = 0, h = -1)
                   panel.bwplot( pch="|", fill=col,...)
               },
               par.settings = list(plot.symbol = list(pch = 4)),
               scales=list(relation="same", alternating=alternating, cex=1.5),
               xlab = xlab,
               ylab = ylab,
               cex.lab=1.5,
               do.out=do.out,
               ...)
    }
}





