make.grid <- function(x, y, x.grid = seq(0, 1025, by=25),
                      y.grid = seq(0, 1025,by=25)) {
  ################
  # INPUT
  ################
  # x   a vector of the data values for the x-axis
  # y   a vector of the data values for the y-axis
  # x.grid   a vector of grid marks to allocate x
  # y.grid   a vector of grid marks to allocate y

  ############
  # OUTPUT
  ############
  # z   matrix of values with counts in an x-y grid
  # n.cells  number of total observation in z
  
  z <- NULL
  nxg <- length(x.grid)
  nyg <- length(y.grid)
  x.c <- as.integer(cut(x,x.grid,right=FALSE))
  y.c <- as.integer(cut(y,y.grid,right=FALSE))

  z <- xtabs(~x.c+y.c,drop.unused.levels=FALSE)

  ## Add empty rows and cols to z:

  zero.rows <- setdiff(seq(1,nxg-1),unique(x.c))
  zero.cols <- setdiff(seq(1,nyg-1),unique(y.c))
  
  if(!is.null(zero.rows) & (length(zero.rows)!=0)){

    orig.row.nm <- rownames(z)
    z <- rbind(z,matrix(rep(rep(0,ncol(z)),length(zero.rows)),
                            nrow=length(zero.rows)))
    
    rownames(z) <- c(orig.row.nm,paste(zero.rows))

    z <- z[order(as.integer(rownames(z))),]

  }

  if(!is.null(zero.cols) & (length(zero.cols)!=0)){

    orig.col.nm <- colnames(z)
    z <- cbind(z,matrix(rep(rep(0,nrow(z)),length(zero.cols)),
                            ncol=length(zero.cols)))

    colnames(z) <- c(orig.col.nm,paste(zero.cols))

    z <- z[,order(as.integer(colnames(z)))]

  }
  
  n.cells <- sum(z)

  return(list(z=z,n.cells=n.cells))

}
