plot.ProbBin.FCS<-function(x, xlab=x$varname,
                           ##ylab="Frequency", 
               xlim=c(min(c(round(range(x$st.hist$breaks),1) + 1, 
                  round(range(x$unst.hist$breaks),1) + 1)), 
                  max(c(round(range(x$st.hist$breaks),1) + 1, 
                  round(range(x$unst.hist$breaks),1) + 1))),
              ## ylim=c(0, x$N.in.bin + 150),
              main="", 
              labels=FALSE, 
              freq=FALSE, 
              plots.made=c("both", "stimulated", "unstimulated"), ...){

  #################################################################################
  #  INPUT VARIABLES
  ############################################################
  # Name       Description
  ############################################################
  # x      ProbBin.FCS object
  #
  # varname    name of the variable to be plotted in the histogram
  # 
  # yht        the frequency height limit of the histograms
  #
  # yupper     the upper y limit on a univariate denisty plot 
  #
  # outputtype the type of output: "ps", "latex", or "none" ????  Maybe for later
  #
  # titl       the title of the file; (ie, individual id number)
  #
  # plot       Boolean; if true than a plot will be shown
  ######################################################################################
  #  OUTPUT
  #######################################################################################
  # 1. histogram of the unstimulated sample for the gamma interferon variable
  # 2. histogram of the stimulated sample for the gamma intereferon variable
  # 3. density smoothing plot of the distributions of stimulated and unstimulated Gamma interferon variable
  #
  #
  # NOTE: Please note that each bin in the histograms will be determined
  # such that the endpoint is included (ie, for a<b, (a,b] is the bin interval.
  #######################################################################################
  if (is(x, "ProbBin.FCS") ==FALSE) {
    stop("not of class ProbBin.FCS")
  }

  plots.made <- match.arg(plots.made)
  
  if ((plots.made=="both") || (plots.made == "stimulated")){
     plot(x$st.hist,  xlim=xlim, ##ylim=ylim,
       xlab=xlab, ##ylab=ylab,
       freq=freq,
       main=paste("Stimulated", main, sep=":"), 
       labels=labels, ...)
  }

  if ((plots.made=="both") || (plots.made == "unstimulated")){

     plot(x$unst.hist,  
       xlim=xlim, ##ylim=ylim,
       xlab=xlab, ##ylab=ylab,
       freq=freq, main=paste("Unstimulated", main, sep=":"), labels=labels, ...)
  }
}
