runflowcytests <- function(controldata,
                           stimuldata, flowcytests=c("WLR", "KS",
                                         "ProbBin.by.control",
                                         "ProbBin.combined", "pkci2"),
                           N.in.bin=100,
                           varname="",
                           title=" ",
                           output.all=FALSE,
                           graph.outlay=c(3,2),
                           crit.pkci2 =0.999,
                           alpha.pkci2=0.05,
                           na.action.WLR=options()$na.action,
                           rho.WLR=0, WLR.plotted=TRUE,
                           
                           alternative.KS="two.sided", ..., KS.plotted=TRUE,
                           PBobj.plotted=TRUE,
                           PBobj.plots.made=c("both", "stimulated", "unstimulated")){

## use individual tests for more details
  
  ########################
  #  INPUT
  ########################
  
  # controldata   a vector of values/fluor measurements
  # stimuldata    a vector of values/fluor measurements
 
  # N.in.bin      a number which denotes the number per bin in
  #                         probability binning for stats.FCS
  # title         the title of the survival curve for weightedlogrank.flowcytest
  # crit.pkci2    the percentile of control sample to use as gate (for pkci2.flowcytest)
  # alpha.pkci2     for construction of (1-alpha)% CI  (for pkci2.flowcytest)
  ##########################
  # OUTPUT
  #########################
  #  Runs the following flowcytests for each cutoff value:
  # 1.  weightedlogrank      weighted log rank test (not sure if the code is correct)
  #                              Survival curve is also output
  # 2.  KS                   Kolmogorov-Smirnoff test
  # 3.  baggerlyNroederer    baggerly & roederer stats
  #                         (Chi-sq and Normal tests for PB metric (probability binning)
  # 4.  pkci2               (95% CI ...)

  # output is rather messy...
 
  pvalues<-pvalues.names<-statistics<-statistics.names<-positions <- NULL
  if (WLR.plotted || KS.plotted || PBobj.plotted){
    par(mfrow=graph.outlay)
  }
  output.list <- list()
  if ("WLR" %in% flowcytests){
    weightedlogrank <- WLR.flowcytest(controldata, stimuldata,
                                      title=title,
                                      varname=varname,
                                      na.action=na.action.WLR,
                                      rho=rho.WLR, WLR.plotted=WLR.plotted)
    statistics <- round(as.numeric(c(weightedlogrank$chisq.WLR)), 3)
    pvalues <-round(as.numeric(c(weightedlogrank$p.val.1sid.chisq.WLR)), 5)
    positions <- 1
    output.list <- c(output.list, list("WLR"=weightedlogrank))
    
  }
  
  if ("KS" %in% flowcytests){
    KS <- KS.flowcytest(controldata, stimuldata,
                        title=title, varname=varname,
                        alternative=alternative.KS, KS.plotted=KS.plotted,...)
    statistics <- c(statistics,round(as.numeric(c( KS$statistic)), 3))
    pvalues <-c(pvalues,round(as.numeric(c(KS$pval.2sid.KS)), 5))
    positions <- c(positions, 2)
    output.list <- c(output.list, list("KS"=KS))
  }

  PBobj.plots.made <- match.arg(PBobj.plots.made)
  if ("ProbBin.by.control" %in% flowcytests){
    PBmetric.bycontrol <- ProbBin.flowcytest(controldata,
                                             stimuldata, varname=varname,
                                             AnalyType="by.control",
                                             title=title, N=N.in.bin, PBobj.plotted=PBobj.plotted,
                                             plots.made=PBobj.plots.made)
    statistics <- c(statistics,round(as.numeric(c(PBmetric.bycontrol$T.chi.unadj,
                                                  PBmetric.bycontrol$T.chi.unadj,
                                                  PBmetric.bycontrol$PBmetric.unadj,
                                                  PBmetric.bycontrol$PBmetric.adj,
                                                  PBmetric.bycontrol$T.chi.adj,
                                                  PBmetric.bycontrol$T.chi.adj,
                                                  PBmetric.bycontrol$pearson.stat,
                                                  PBmetric.bycontrol$pearson.stat)), 3))
    pvalues <-c(pvalues,round(as.numeric(c(PBmetric.bycontrol$p.val.2tail.z.unadj,
                                           PBmetric.bycontrol$p.val.1tail.z.unadj,
                                           NA,
                                           PBmetric.bycontrol$p.val.1tail.chi.adj,
                                           PBmetric.bycontrol$p.val.1tail.z.adj,
                                           PBmetric.bycontrol$p.val.2tail.z.adj,
                                           PBmetric.bycontrol$pearson.p.value,
                                           PBmetric.bycontrol$pearson.p.val.PB.df)), 5))
    positions <- c(positions, 3:10)
    output.list <- c(output.list, list("ProbBin.by.control"=PBmetric.bycontrol))
    
  }
  if ("ProbBin.combined" %in% flowcytests){
    PBmetric.combined<- ProbBin.flowcytest(controldata,
                                           stimuldata, varname=varname,
                                           AnalyType="combined",
                                           title=title, N=N.in.bin, PBobj.plotted=PBobj.plotted,
                                           plots.made=PBobj.plots.made)
    statistics <- c(statistics,round(as.numeric(c( PBmetric.combined$T.chi.unadj,
                                                  PBmetric.combined$T.chi.unadj,
                                                  PBmetric.combined$PBmetric.unadj,
                                                  PBmetric.combined$PBmetric.adj,
                                                  PBmetric.combined$T.chi.adj,
                                                  PBmetric.combined$T.chi.adj,
                                                  PBmetric.combined$pearson.stat,
                                                  PBmetric.combined$pearson.stat)), 3))
    pvalues <-c(pvalues,round(as.numeric(c(PBmetric.combined$p.val.2tail.z.unadj,
                                           PBmetric.combined$p.val.1tail.z.unadj,
                                           NA,
                                           PBmetric.combined$p.val.1tail.chi.adj,
                                           PBmetric.combined$p.val.1tail.z.adj,
                                           PBmetric.combined$p.val.2tail.z.adj,
                                           PBmetric.combined$pearson.p.value,
                                           PBmetric.combined$pearson.p.val.PB.df)), 5))
    positions <- c(positions, 11:18)
    output.list <- c(output.list, list("ProbBin.combined"=PBmetric.combined))
  }
  if ("pkci2" %in% flowcytests){
    
    pkci2<- pkci2.flowcytest(controldata, stimuldata,
                             crit=crit.pkci2,
                             alpha=alpha.pkci2)
    statistics <- c(statistics,round(as.numeric(c( pkci2$pc.hat.pkci2,
                                                  pkci2$pc.hat.pkci2)), 3))
    pvalues <-c(pvalues,round(as.numeric(c( pkci2$pval1.pkci2,
                                           pkci2$pval2.pkci2)), 5))
    
    positions <- c(positions, 19:20)
    output.list <- c(output.list, list("pkci2"=pkci2))
  }
  
  
 
  pvalues.names <- c("p.val.1sid.chisq.WLR",
                     "pval.2sid.KS",
                     
                     "p.val.2tailz.unadj",
                     "p.val.1tailz.unadj",
                     "",
                     
                     "p.val.1tail.chi.adj",
                     "p.val.1tail.z.adj",
                     "p.val.2tail.z.adj",
                     
                     "p.val.pearson.adj",
                     "p.val.pearson.PBdf",
                     
                     "p.val.2tailz.unadj",
                     "p.val.1tailz.unadj",
                     "", 
                     "p.val.1tail.chi.adj",
                     "p.val.1tail.z.adj",
                     "p.val.2tail.z.adj",
                     "p.val.pearson.adj",
                     "p.val.pearson.PBdf",
                     "pval1.pkci2",
                     "pval2.pkci2")
  
  
  ## inclue the combined too
  statistics.names <- c("chisq.WLR",
                        "KS statistic",
                        "T.chi.unadj.PB.bycontrol",
                        "T.chi.unadj.PB.bycontrol",
                        "PBmetric.unadj.PB.bycontrol",
                        "PBmetric.adj.PB.bycontrol",
                        "T.chi.adj.PB.bycontrol",
                        "T.chi.adj.PB.bycontrol",
                        "pearson.stat.PB.bycontrol",
                        "pearson.stat.PB.bycontrol",
                        "T.chi.unadj.PB.combined",
                        "T.chi.unadj.PB.combined",
                        "PBmetric.unadj.PB.combined",
                        "PBmetric.adj.PB.combined",
                        "T.chi.adj.PB.combined",
                        "T.chi.adj.PB.combined",
                        "pearson.stat.PB.combined",
                        "pearson.stat.PB.combined",
                        "pc.hat.pkci2",
                        "pc.hat.pkci2")


  list.info <- data.frame(statistics.names[positions],
                          statistics,
                          pvalues.names[positions],
                          pvalues)
  
  
  if (output.all){
    return(output.list)
  } else {
    return(list.info)
  }
}

