\name{"FCSgate-class"}
\docType{class}
\alias{"FCSgate-class"}
\alias{"FCSgate"}
\alias{FCSgate-class}
\alias{FCSgate}

\title{Class "FCSgate" Flow Cytometry Standard extension to gating}
\description{ This class of objects extends the class \code{FCS-class}
  to incorporate information from gating which is a procedure by which
  rows or cells from the data are selected via one or two dimensional
  value restrictions or gating ranges.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("FCSgate", ...)}.
  Essentially this new object includes the \code{FCS-class} object.
}
\section{Slots}{
  \describe{
    \item{\code{gate}:}{Object of class \code{"matrix"} containing the
      gating indices such that each column corresponds to a different
      gating procedure/index and the rows correspond to the positions of
      the \bold{original} row/cell observations. }
    
    \item{\code{history}:}{Object of class \code{"vector"} containing the
      gating history strings such that each vector element corresponds
      to a different gating procedure/index and each string contains
      information about the particular gate, column variables that were
      used, and other additional comments.}
    
    \item{\code{extractGatedData.msg}:}{Object of class \code{"vector"}
      containing strings describing any extraction that took place
      corresponding to each gating procedure/index and history string; each
      string contains information about the particular corresponding
      gate column position and gate name and what value index was for
      inclusion/selection (ie, IndexValue.In)}
    
    \item{\code{current.data.obs}:}{Object of class \code{"vector"}
      contains the current data positional values from the original data }
    \item{\code{data}:}{Object of class \code{"matrix"} which holds
      integer data such that the columns are the variables (usually
      immunofluorescence measurements) and the rows are the cell
      observations. }
    \item{\code{metadata}:}{Object of class \code{"FCSmetadata"} which
      holds information about the file, data, and column variables among
      other items in the header of the original raw FCS binary file. }
  }
}
\section{Extends}{
Class \code{"FCS"}, directly.
}
\section{Methods}{
 No methods defined with class "FCSgate" in the signature. 
}
\references{
  Trevor Hastie, Robert Tibshirani, and Jerome Friedman. The
  Elements of Statistical Learning: Data Mining, Inference, and
  Prediction. Springer Series in Statistics : New York, 2001. pp.279-283.

  Jerome H. Friedman and Nicholas I. Fisher. Bump Hunting in
  High-Dimensional Data. Tech Report. October 28, 1998.

  J. Paul Robinson, et al. Current Protocols in Cytometry.  John Wiley
  \& Sons, Inc : 2001.

  Mario Roederer and Richard R. Hardy. Frequency Difference Gating: A
  Multivariate Method for Identifying Subsets that Differe between
  Samples. Cytometry, 45:56-64, 2001.

  Mario Roederer and Adam Treister and Wayne Moore and Leonore
  A. Herzenberg. Probability Binning Comparison: A Metric for
  Quantitating Univariate Distribution Differences. Cytometry, 45:37-46,
  2001.

  Keith A. Baggerly. Probability Binning and Testing Agreement between
  Multivariate Immunofluorescence Histograms: Extending the Chi-Squared
  Test. Cytometry, 45:141-150, 2001.
  
}
\author{A.J. Rossini, J.Y. Wan, and Zoe Moodie}

\note{The methods \code{createGate} and \code{icreateGate}, functionally
  without plots
  or interactively with plots, respectively, extends the
  \code{FCS-class} to the
  FCSgate-class.  Some interactive gating schemes are noted in \code{FHCRC.HVTNFCS}
  and \code{VRC.HVTNFCS}.  Further testing after gating is implemented by
  \code{runflowcytests} on the particular variable of interest which is
  usually the Interferon Gamma Immunofluoroescence measurement.}

\seealso{
  \code{\link{createGate}},
  \code{\link{icreateGate}},
  \code{\link{extractGatedData}},
  \code{\link{extractGateHistory}},
  \code{\link{FHCRC.HVTNFCS}},
  \code{\link{VRC.HVTNFCS}},
  \code{\link{"FCS-class"}},
  \code{\link{runflowcytests}} 
}
\examples{
default.FCSgateobj<-new("FCSgate")
}
\keyword{classes}
