\name{xgobi.FCS}
\alias{xgobi.FCS}
\title{XGobi: Dynamic Graphics for Data Analysis on FCS R objects}
\description{
  This function allows for a multidimensional view/manipulation
  of the data of the FCS object.  Each row is an observation/cell,
  and the columns are regarded as the different variable conditions.
}
\usage{
  xgobi.FCS(myFCSobj, subset.row = NULL, subset.col = NULL, ...)
}
\arguments{
  \item{myFCSobj}{FCS object}
  \item{subset.row}{a vector of the row positions to be displayed; by default
          the first 1/15th rows are chosen to be displayed}
  \item{subset.col}{a vector of the column positions to be displayed; by
          default the first 1/2 of the columns are displayed}
  \item{\dots}{additional 'xgobi' function parameters/options in 'xgobi'
  package}
}

\value{
   A graphics window with user-enabled manipulations The UNIX
   `status' upon completion, i.e. `0' if ok.
}
\references{
  Please see 'xgobi' in 'xgobi' package.
  \describe{
  \item{websites}{<URL: http://www.research.att.com/areas/stat/xgobi/>,
    <URL: http://www.public.iastate.edu/~dicook/>}
  \item{of R port}{ Kurt Hornik and Martin Maechler
    \email{maechler@stat.math.ethz.ch}}
  }
}
\author{A.J. Rossini and J.Y. Wan}
\note{
  By default only a subset of the data is shown in xgobi because of size
  limitations.  The user may be able to view the whole FCS dataset by
  using xgobi, but only if the dataset is not too huge for xgobi
  capabilities.  It may be advisable to \code{\link{createGate}} and
  \code{\link{extractGatedData}} before viewing with xgobi.
}
\section{WARNING}{
  Abuses/uses xgobi: XGobi cannot handle datasets that are too
  large.  Therefore, use subset.col and subset.row options to reduce
  the data matrix of the FCS R-object.  Please see `xgobi' for other
  commands in the signature.
}
\seealso{'xgobi' in \pkg{xgobi} package,
  \code{\link{plot-methods}},\code{\link{plotvar.FCS}},
  \code{\link{createGate}}, \code{\link{extractGatedData}},
  \code{\link{icreateGate}}}
\examples{

  if (require(xgobi)) {
   if (require(rfcdmin)){
    ## obtaining the FCS objects from VRC data
    if (!(is.element("unst.1829", objects()))) {
      data(VRCmin)
    }
    if (interactive()==TRUE) {
      ## plots first 1/15 rows
      ## plots first 1/2 columns
      xgobi.FCS(unst.1829, title="unst.1829 default subset")

      ## plots all the rows
      ## plots only the first 3 columns
      xgobi.FCS(unst.1829, subset.row=1:6000, subset.col=1:2,
                title="unst.1829 first 6000 rows/cells with 2 column params")
    }
  }
 }
}
\keyword{hplot}
\keyword{manip}
