rm(list=ls())


## Create example and then test:
## An example FCS S4 object

if (!require(rfcdmin)){
  stop("rfcdmin missing: can't test file loading.")
}

##if (!require(rfcdorig)){
##  library(rfcdorig, lib.loc="~/lib/R")
##}
##if (!require(rfcdfhcrc2)){
##  library(rfcdfhcrc2, lib.loc="~/lib/R")
##}

if (!require(rflowcyt)){
  stop("rflowcyt missing: can't test file loading.")
}

################################
### Trying to read all binary files
## we want to test
##############################

read.FCS.test <- function(data.pack, list.FCSRobj=NULL){
  ## data.pack is the character name of the fcs binary package name
  ## currently only "rfcdmin" works for a comparison to archived S4 FCS-class R objects
  data.dir <- system.file("fcs", package=data.pack)
  
  fcs.files <- dir(data.dir)
  split.fcs.filenames <- strsplit(fcs.files, "\\.")
  index.fcs <- unlist(lapply(split.fcs.filenames,
                             function(x) {
                               ending <- x[length(x)]
                               if (ending=="fcs"){
                                 return(1)
                               } else {
                                 return(0)
                               }
                             }))

  fcs.files <- fcs.files[index.fcs==1]
  
  if ("StopOnError" %in% objects()){
    if (!is.logical(StopOnError)) {
      ## default is TRUE when StopOnError is not boolean
      StopOnError <- TRUE
    }    
  } else {
    ## default is to stop when there is an error 
    StopOnError <- TRUE
  }

  ErrorMsg <- NULL
  FailedTestObjName <- NULL
  error.printed <- names.failed <- NULL

  for (j in 1:length(fcs.files)){
    fileFCS <- paste(data.dir, "/", fcs.files[j], sep="")
    
    cat("Reading file:", fileFCS, "\n\n")
    tmp.FCS <- read.FCS(fileFCS)
    cat("\n\n")
 
    if (is.null(list.FCSRobj)){
      ## no comparisons are made
    } else {
      ## compare
      ArchivedFCSRobj <- get(list.FCSRobj[j])
      if (!equals(ArchivedFCSRobj, tmp.FCS)){
        ErrorMsg <- c(ErrorMsg,
                      paste("read.FCS-tests ERROR : Cannot read in correctly the file",
                            fileFCS))
        FailedTestObjName <- c(FailedTestObjName, fileFCS)
        ArchivedFCSRobj <- c(ArchivedFCSRobj,  list.FCSRobj[j])
        if (StopOnError){ 
          stop(paste("read.FCS-tests ERROR : Cannot read in correctly the file", fileFCS,
                     "to match with the archived file",list.FCSRobj[j] ))
        } else {
          print(paste("read.FCS-tests ERROR : Cannot read in correctly the file",
                      fileFCS, "to match with the archived file",list.FCSRobj[j] ))
        }
        
      } else {
        print(paste("read.FCS-tests SUCCESS : Able to read in correctly the file",
                    fileFCS,"to match with the archived file",list.FCSRobj[j]  ))
      }

    }
  }
  
  if (is.null(FailedTestObjName) & is.null(ErrorMsg)){
    names.failed <- "None; all FCSmetadataclass tests were successful."
    error.printed <- "None; all FCSmetadataclass tests were successful."
  } else {
    names.failed <- matrix(c(FailedTestObjName, ArchivedFCSRobj), ncol=2)
    error.printed <- ErrorMsg
  }
  cat("These are the following file objects and Archived S4 FCS R objects that have failed: \n\n")
  print(names.failed)
  cat("\n\n\n")
  cat("These are the corresponding Error Messages: \n\n")
  print(error.printed)
  

}

## testing the data from package = rfcdorig
cat("\n\n", "read.FCS.test: package = rfcdmin", "\n\n")
data(FCSRobjmin)

## commented out until we fix the stored copy!
## read.FCS.test("rfcdmin", list.FCSRobj=ls()[(ls() != "read.FCS.test") &(ls() != "last.warning") ])




### testing the data from package = rfcdfhcrc2
## NOTE: There are too many files, but they all read. 
## cat("\n\n", "read.FCS.test: package = rfcdfhcrc2", "\n\n")
## read.FCS.test("rfcdfhcrc2")

### Misc code for setting things up
## results <- read.FCS("/usr/local/lib/R/site-library/rfcdmin/fcs/SEB-NP22.fcs")
## save(results,file="SEB-NP22.FCSRobj")
## load("/home/rossini/Repos/repos-tla/rflowcyt--laptop--0/rfcdmin/data/")
## SEB.NP22.FCSRobj <- read.FCS("/home/rossini/Repos/repos-tla/rflowcyt--laptop--0/rfcdmin/inst/fcs/SEB-NP22.fcs")
## facscan256.FCSRobj <- read.FCS("/home/rossini/Repos/repos-tla/rflowcyt--laptop--0/rfcdmin/inst/fcs/facscan256.fcs")
## save(list=c("  "),file="  ")
